/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../../../environments";
import * as core from "../../../../../../core";
import * as Merge from "../../../../../index";
export declare namespace Contacts {
    interface Options {
        environment?: core.Supplier<environments.MergeEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        /** Override the X-Account-Token header */
        accountToken?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Account-Token header */
        accountToken?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Contacts {
    protected readonly _options: Contacts.Options;
    constructor(_options: Contacts.Options);
    /**
     * Returns a list of `Contact` objects.
     *
     * @param {Merge.crm.ContactsListRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.list()
     */
    list(request?: Merge.crm.ContactsListRequest, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.PaginatedContactList>;
    private __list;
    /**
     * Creates a `Contact` object with the given values.
     *
     * @param {Merge.crm.CrmContactEndpointRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.create({
     *         model: {}
     *     })
     */
    create(request: Merge.crm.CrmContactEndpointRequest, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.CrmContactResponse>;
    private __create;
    /**
     * Returns a `Contact` object with the given `id`.
     *
     * @param {string} id
     * @param {Merge.crm.ContactsRetrieveRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.retrieve("id")
     */
    retrieve(id: string, request?: Merge.crm.ContactsRetrieveRequest, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.Contact>;
    private __retrieve;
    /**
     * Updates a `Contact` object with the given `id`.
     *
     * @param {string} id
     * @param {Merge.crm.PatchedCrmContactEndpointRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.partialUpdate("id", {
     *         model: {}
     *     })
     */
    partialUpdate(id: string, request: Merge.crm.PatchedCrmContactEndpointRequest, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.CrmContactResponse>;
    private __partialUpdate;
    /**
     * Ignores a specific row based on the `model_id` in the url. These records will have their properties set to null, and will not be updated in future syncs. The "reason" and "message" fields in the request body will be stored for audit purposes.
     *
     * @param {string} modelId
     * @param {Merge.crm.IgnoreCommonModelRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.ignoreCreate("model_id", {
     *         reason: "GENERAL_CUSTOMER_REQUEST"
     *     })
     */
    ignoreCreate(modelId: string, request: Merge.crm.IgnoreCommonModelRequest, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<void>;
    private __ignoreCreate;
    /**
     * Returns metadata for `CRMContact` PATCHs.
     *
     * @param {string} id
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.metaPatchRetrieve("id")
     */
    metaPatchRetrieve(id: string, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.MetaResponse>;
    private __metaPatchRetrieve;
    /**
     * Returns metadata for `CRMContact` POSTs.
     *
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.metaPostRetrieve()
     */
    metaPostRetrieve(requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.MetaResponse>;
    private __metaPostRetrieve;
    /**
     * Returns a list of `RemoteFieldClass` objects.
     *
     * @param {Merge.crm.ContactsRemoteFieldClassesListRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.crm.contacts.remoteFieldClassesList()
     */
    remoteFieldClassesList(request?: Merge.crm.ContactsRemoteFieldClassesListRequest, requestOptions?: Contacts.RequestOptions): core.HttpResponsePromise<Merge.crm.PaginatedRemoteFieldClassList>;
    private __remoteFieldClassesList;
    protected _getAuthorizationHeader(): Promise<string>;
}
