/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../../../environments";
import * as core from "../../../../../../core";
import * as Merge from "../../../../../index";
export declare namespace Invoices {
    interface Options {
        environment?: core.Supplier<environments.MergeEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        /** Override the X-Account-Token header */
        accountToken?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Account-Token header */
        accountToken?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Invoices {
    protected readonly _options: Invoices.Options;
    constructor(_options: Invoices.Options);
    /**
     * Returns a list of `Invoice` objects.
     *
     * @param {Merge.accounting.InvoicesListRequest} request
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.list()
     */
    list(request?: Merge.accounting.InvoicesListRequest, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.PaginatedInvoiceList>;
    private __list;
    /**
     * Creates an `Invoice` object with the given values.
     *             Including a `PurchaseOrder` id in the `purchase_orders` property will generate an Accounts Payable Invoice from the specified Purchase Order(s).
     *
     *
     * @param {Merge.accounting.InvoiceEndpointRequest} request
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.create({
     *         model: {}
     *     })
     */
    create(request: Merge.accounting.InvoiceEndpointRequest, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.InvoiceResponse>;
    private __create;
    /**
     * Returns an `Invoice` object with the given `id`.
     *
     * @param {string} id
     * @param {Merge.accounting.InvoicesRetrieveRequest} request
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.retrieve("id")
     */
    retrieve(id: string, request?: Merge.accounting.InvoicesRetrieveRequest, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.Invoice>;
    private __retrieve;
    /**
     * Updates an `Invoice` object with the given `id`.
     *
     * @param {string} id
     * @param {Merge.accounting.PatchedInvoiceEndpointRequest} request
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.partialUpdate("id", {
     *         model: {}
     *     })
     */
    partialUpdate(id: string, request: Merge.accounting.PatchedInvoiceEndpointRequest, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.InvoiceResponse>;
    private __partialUpdate;
    /**
     * Returns a list of `RemoteFieldClass` objects.
     *
     * @param {Merge.accounting.InvoicesLineItemsRemoteFieldClassesListRequest} request
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.lineItemsRemoteFieldClassesList()
     */
    lineItemsRemoteFieldClassesList(request?: Merge.accounting.InvoicesLineItemsRemoteFieldClassesListRequest, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.PaginatedRemoteFieldClassList>;
    private __lineItemsRemoteFieldClassesList;
    /**
     * Returns metadata for `Invoice` PATCHs.
     *
     * @param {string} id
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.metaPatchRetrieve("id")
     */
    metaPatchRetrieve(id: string, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.MetaResponse>;
    private __metaPatchRetrieve;
    /**
     * Returns metadata for `Invoice` POSTs.
     *
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.metaPostRetrieve()
     */
    metaPostRetrieve(requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.MetaResponse>;
    private __metaPostRetrieve;
    /**
     * Returns a list of `RemoteFieldClass` objects.
     *
     * @param {Merge.accounting.InvoicesRemoteFieldClassesListRequest} request
     * @param {Invoices.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.accounting.invoices.remoteFieldClassesList()
     */
    remoteFieldClassesList(request?: Merge.accounting.InvoicesRemoteFieldClassesListRequest, requestOptions?: Invoices.RequestOptions): core.HttpResponsePromise<Merge.accounting.PaginatedRemoteFieldClassList>;
    private __remoteFieldClassesList;
    protected _getAuthorizationHeader(): Promise<string>;
}
